@@ -1,4 +1,4 @@
 from .registry import GitLabRegistry, AuthTokenError, ImageDeleteError
 from ._version import __version__, __version_info__  # noqa: F401
 
-__all__ = ('GitLabRegistry', 'AuthTokenError', 'ImageDeleteError')
+__all__ = ("GitLabRegistry", "AuthTokenError", "ImageDeleteError")
